==> afnix_1.5.2.orig.tar.gz: afnix-src-1-5-2/src/srv/wax/shl/Libwax.hpp <==
// ---------------------------------------------------------------------------
// - Libwax.hpp                                                              -
// - afnix:wax service - static entry point declaration                      -
// ---------------------------------------------------------------------------
// - This program is free software;  you can redistribute it  and/or  modify -
// - it provided that this copyright notice is kept intact.                  -
// -                                                                         -
// - This program  is  distributed in  the hope  that it will be useful, but -
// - without  any  warranty;  without  even   the   implied    warranty   of -
// - merchantability or fitness for a particular purpose.  In no event shall -
// - the copyright holder be liable for any  direct, indirect, incidental or -
// - special damages arising in any way out of the use of this software.     -
// ---------------------------------------------------------------------------
// - copyright (c) 1999-2007 amaury darsch                                   -
// ---------------------------------------------------------------------------

#ifndef  AFNIX_LIBWAX_HPP
#define  AFNIX_LIBWAX_HPP

#ifndef  AFNIX_INTERP_HPP
#include "Interp.hpp"
#endif

namespace afnix {

  /// this file contains the module initialization routine for the
  /// wax application management (wax) service
  /// @author amaury darsch

  /// initialize the afnix:wax service
  /// @param interp the current interpreter
  /// @param argv   the arguments vector
  Object* init_afnix_wax (Interp* interp, Vector* argv);
}

#endif

==> afnix_2.1.1.orig.tar.gz: afnix-src-2-1-1/src/srv/wax/shl/Libwax.hpp <==
// ---------------------------------------------------------------------------
// - Libwax.hpp                                                              -
// - afnix:wax service - static entry point declaration                      -
// ---------------------------------------------------------------------------
// - This program is free software;  you can redistribute it  and/or  modify -
// - it provided that this copyright notice is kept intact.                  -
// -                                                                         -
// - This program  is  distributed in  the hope  that it will be useful, but -
// - without  any  warranty;  without  even   the   implied    warranty   of -
// - merchantability or fitness for a particular purpose.  In no event shall -
// - the copyright holder be liable for any  direct, indirect, incidental or -
// - special damages arising in any way out of the use of this software.     -
// ---------------------------------------------------------------------------
// - copyright (c) 1999-2011 amaury darsch                                   -
// ---------------------------------------------------------------------------

#ifndef  AFNIX_LIBWAX_HPP
#define  AFNIX_LIBWAX_HPP

#ifndef  AFNIX_INTERP_HPP
#include "Interp.hpp"
#endif

namespace afnix {

  /// this file contains the initialization routine for the wax application
  /// management (wax) service
  /// @author amaury darsch

  /// initialize the afnix:wax service
  /// @param interp the current interpreter
  /// @param argv   the arguments vector
  Object* init_afnix_wax (Interp* interp, Vector* argv);
}

#endif
